"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// tslint:disable-next-line:no-var-requires
var plantuml = require("node-plantuml"); // there are no type definitions for this module :-(
var fs = require("fs");
var path = require("path");
/**
 * Generates local image files.
 */
var ImageGenerator = /** @class */ (function () {
    function ImageGenerator() {
        /** Stamp used for every image file. */
        this.fileNameStamp = "umlClassDiagram";
        /** Number of generated image files. */
        this.numberOfGeneratedImages = 0;
    }
    /**
     * Sets the output directory.
     * @param outputDirectory The path to the folder into which the files are generated.
     */
    ImageGenerator.prototype.setOutputDirectory = function (outputDirectory) {
        this.outputDirectory = outputDirectory;
    };
    /**
     * Writes a class diagram as a local image to the disc.
     * @param encodedPlantUml The encoded PlantUML code for the image.
     * @param imageName The name of the class diagram.
     * @param imageFormat The format of the image to generate. (eg.: "png" or "svg")
     * @returns Absolute path to the written file.
     */
    ImageGenerator.prototype.writeImageFile = function (encodedPlantUml, imageName, imageFormat) {
        var filename = this.createFilenameForNextImage(imageName, imageFormat);
        var absoluteFilename = path.join(this.outputDirectory, filename);
        var decode = plantuml.decode(encodedPlantUml);
        var gen = plantuml.generate({ format: imageFormat });
        decode.out.pipe(gen.in);
        gen.out.pipe(fs.createWriteStream(absoluteFilename));
        ++this.numberOfGeneratedImages;
        return absoluteFilename;
    };
    /**
     * Creates a filename for the next image.
     * @param imageName A name of the thing visible on the image.
     * @param fileExtension Extension used in the filename.
     * @returns The generated filename.
     */
    ImageGenerator.prototype.createFilenameForNextImage = function (imageName, fileExtension) {
        return imageName + "-" + this.fileNameStamp + "-" + this.numberOfGeneratedImages + "." + fileExtension;
    };
    return ImageGenerator;
}());
exports.ImageGenerator = ImageGenerator;
